@@ -593,13 +593,50 @@ class TomographyInversionApp(object):
             ax.set_ylabel("Tx")
         plt.tight_layout()
 
+    def plot_tikhonov_curves(self, save):
+        fig, ax = plt.subplots(1, 3, figsize=(12, 4))
+
+        beta = np.array(save.beta)
+        # account for the 1/2 so phi_d* = nD
+        phi_d = 2*np.array(save.phi_d)
+        phi_m = 2*np.array(save.phi_m)
+        nD = save.survey[0].nD
+
+        ax[0].semilogx(beta, phi_d)
+        ax[0].semilogx(beta, np.ones_like(beta)*nD, '--k')
+        ax[0].set_xlim(np.hstack(beta).max(), np.hstack(beta).min())
+        ax[0].set_xlabel("$\\beta$", fontsize=14)
+        ax[0].set_ylabel("$\phi_d$", fontsize=14)
+        ax[0].plot(beta[save.i_target], phi_d[save.i_target], "k*", ms=10)
+        ax[0].text(
+            beta[save.i_target], nD+20,
+            f"iter {save.i_target}",
+            ha="left",
+            fontsize=16
+        )
+
+        ax[1].semilogx(beta, phi_m)
+        ax[1].set_xlim(np.hstack(beta).max(), np.hstack(beta).min())
+        ax[1].set_xlabel("$\\beta$", fontsize=14)
+        ax[1].set_ylabel("$\phi_m$", fontsize=14)
+        ax[1].plot(beta[save.i_target], phi_m[save.i_target], "k*", ms=10)
+
+        ax[2].plot(phi_m, phi_d)
+        ax[2].set_xlim(np.hstack(phi_m).min(), np.hstack(phi_m).max())
+        ax[2].set_xlabel("$\phi_m$", fontsize=14)
+        ax[2].set_ylabel("$\phi_d$", fontsize=14)
+        ax[2].plot(phi_m[save.i_target], phi_d[save.i_target], "k*", ms=10)
+
+        plt.tight_layout()
+        return ax
+
     def interact_model_inversion(self, model, clim=None):
         def foo(ii, fixed=False):
             self.plot_model_inversion(ii, model, fixed=fixed, clim=clim)
 
         interact(
             foo,
-            ii=IntSlider(min=0, max=len(model) - 1, step=1, value=len(model) - 1),
+            ii=IntSlider(min=0, max=len(model) - 1, step=1, value=0),
             continuous_update=False,
         )
 
@@ -613,7 +650,7 @@ class TomographyInversionApp(object):
                 min=0,
                 max=len(pred) - 1,
                 step=1,
-                value=len(pred) - 1,
+                value=0,
                 continuous_update=False,
             ),
         )
